@@ -2,7 +2,8 @@
 # Copyright (c) Max-Planck-Institut für Eisenforschung GmbH - Computational Materials Design (CM) Department
 # Distributed under the terms of "New BSD License", see the LICENSE file.
 
-# API of the pyiron_base module - in alphabetical order 
+from pyiron_base.state import state
+# API of the pyiron_base module - in alphabetical order
 from pyiron_base.generic.factory import PyironFactory
 from pyiron_base.generic.flattenedstorage import FlattenedStorage
 from pyiron_base.generic.hdfio import FileHDFio, ProjectHDFio
@@ -27,8 +28,8 @@ from pyiron_base.master.flexible import FlexibleMaster
 from pyiron_base.project.generic import Project, Creator
 from pyiron_base.pyio.parser import Logstatus, extract_data_from_file
 from pyiron_base.server.queuestatus import validate_que_request
-from pyiron_base.settings.generic import Settings
-from pyiron_base.settings.install import install_dialog
+from pyiron_base.state.settings import Settings
+from pyiron_base.state.install import install_dialog
 from pyiron_base.table.datamining import PyironTable, TableJob
 from pyiron_base.generic.object import HasDatabase, HasStorage, PyironObject
 from pyiron_base.database.performance import get_database_statistics
