@@ -5,13 +5,16 @@
 DatabaseAccess class deals with accessing the database
 """
 
-import pyiron_base.settings.logger
-
+from pyiron_base.state.logger import logger
+from abc import ABC, abstractmethod
+import warnings
 import numpy as np
 import re
 import time
 import os
 from datetime import datetime
+from pyiron_base.generic.util import deprecate
+import pandas
 from sqlalchemy import (
     create_engine,
     MetaData,
@@ -38,6 +41,220 @@ __email__ = "janssen@mpie.de"
 __status__ = "production"
 __date__ = "Sep 1, 2017"
 
+class IsDatabase(ABC):
+    """
+    Captures common interface for all database types in pyiron, e.g. SQL/SQLite/FileTable.
+    """
+
+    @abstractmethod
+    def _get_view_mode(self):
+        pass
+
+    @property
+    def view_mode(self):
+        """
+        Get view_mode - if view_moded is enable pyiron has read only access to the database.
+
+        Some implementations do not allow to set this value.
+
+        Returns:
+            bool: True when view_mode is enabled
+        """
+        return self._get_view_mode()
+
+    @property
+    @deprecate("use view_mode")
+    def viewer_mode(self):
+        return self.view_mode
+    viewer_mode.__doc__ = view_mode.__doc__
+
+    @abstractmethod
+    def _get_job_table(
+            self,
+            sql_query,
+            user,
+            project_path,
+            recursive=True,
+            columns=None,
+            element_lst=None,
+    ):
+        pass
+
+    @staticmethod
+    def _get_filtered_job_table(df: pandas.DataFrame, **kwargs: dict) -> pandas.DataFrame:
+        """
+        Get a job table in a project based on matching values from any column in the project database
+
+        Args:
+            df (pandas.DataFrame): DataFrame to be filtered
+            **kwargs (dict): Optional arguments for filtering with keys matching the project database column name
+                            (eg. status="finished")
+
+        Returns:
+            list: DataFrame containing filtered jobs
+        """
+        if len(kwargs) == 0 or df.empty:
+            return df
+        mask = np.ones_like(df.index, dtype=bool)
+        for key in kwargs.keys():
+            if key not in list(df.columns):
+                raise ValueError("Column name {} does not exist in the project database!")
+        for key, val in kwargs.items():
+            if val is None:
+                mask &= df[key].isnull()
+            elif str(val).startswith('*') and str(val).endswith('*'):
+                mask &= df[key].str.contains(str(val).replace('*', ''))
+            elif str(val).endswith('*'):
+                mask &= df[key].str.startswith(str(val).replace('*', ''))
+            elif str(val).startswith('*'):
+                mask &= df[key].str.endswith(str(val).replace('*', ''))
+            else:
+                mask &= df[key] == val
+        return df[mask]
+
+    def job_table(
+            self,
+            sql_query,
+            user,
+            project_path,
+            recursive=True,
+            columns=None,
+            all_columns=False,
+            sort_by="id",
+            max_colwidth=200,
+            full_table=False,
+            element_lst=None,
+            job_name_contains='',
+            **kwargs,
+    ):
+        """
+        Access the job_table.
+
+        Args:
+            sql_query (str): SQL query to enter a more specific request
+            user (str): username of the user whoes user space should be searched
+            project_path (str): root_path - this is in contrast to the project_path in GenericPath
+            recursive (bool): search subprojects [True/False]
+            columns (list): by default only the columns ['job', 'project', 'chemicalformula'] are selected, but the
+                            user can select a subset of ['id', 'status', 'chemicalformula', 'job', 'subjob', 'project',
+                            'projectpath', 'timestart', 'timestop', 'totalcputime', 'computer', 'hamilton', 'hamversion',
+                            'parentid', 'masterid']
+            all_columns (bool): Select all columns - this overwrites the columns option.
+            sort_by (str): Sort by a specific column
+            max_colwidth (int): set the column width
+            full_table (bool): Whether to show the entire pandas table
+            element_lst (list): list of elements required in the chemical formular - by default None
+            job_name_contains (str): (deprecated) A string which should be contained in every job_name
+            **kwargs (dict): Optional arguments for filtering with keys matching the project database column name
+                            (eg. status="finished"). Asterisk can be used to denote a wildcard, for zero or more
+                            instances of any character
+
+        Returns:
+            pandas.Dataframe: Return the result as a pandas.Dataframe object
+        """
+        if columns is None:
+            columns = ["job", "project", "chemicalformula"]
+        if all_columns:
+            columns = [
+                "id",
+                "status",
+                "chemicalformula",
+                "job",
+                "subjob",
+                "projectpath",
+                "project",
+                "timestart",
+                "timestop",
+                "totalcputime",
+                "computer",
+                "hamilton",
+                "hamversion",
+                "parentid",
+                "masterid",
+            ]
+        if sort_by not in columns:
+            columns = list(columns) + [sort_by]
+        if full_table:
+            pandas.set_option('display.max_rows', None)
+            pandas.set_option('display.max_columns', None)
+        else:
+            pandas.reset_option('display.max_rows')
+            pandas.reset_option('display.max_columns')
+        pandas.set_option("display.max_colwidth", max_colwidth)
+        df = self._get_job_table(
+                user=user,
+                sql_query=sql_query,
+                project_path=project_path,
+                recursive=recursive,
+                columns=columns,
+        )
+        if job_name_contains != '':
+            warnings.warn("`job_name_contains` is deprecated - use `job='*term*'` instead")
+            kwargs['job'] = '*{}*'.format(job_name_contains)
+        df = self._get_filtered_job_table(df, **kwargs)
+        if sort_by is not None:
+            return df.sort_values(by=sort_by)
+        return df
+
+    @abstractmethod
+    def _get_table_headings(self, table_name=None):
+        pass
+
+    def get_table_headings(self, table_name=None):
+        """
+        Get column names; if given table_name can select one of multiple tables defined in the database, but subclasses
+        may ignore it
+
+        Args:
+            table_name (str): simple string of a table_name like: 'jobs_username'
+
+        Returns:
+            list: list of column names like:
+                ['id',
+                'parentid',
+                'masterid',
+                'projectpath',
+                'project',
+                'job',
+                'subjob',
+                'chemicalformula',
+                'status',
+                'hamilton',
+                'hamversion',
+                'username',
+                'computer',
+                'timestart',
+                'timestop',
+                'totalcputime']
+        """
+        return self._get_table_headings(table_name=table_name)
+
+    @deprecate("use get_table_headings()")
+    def get_db_columns(self):
+        """
+        Get column names
+
+        Returns:
+            list: list of column names like:
+                ['id',
+                'parentid',
+                'masterid',
+                'projectpath',
+                'project',
+                'job',
+                'subjob',
+                'chemicalformula',
+                'status',
+                'hamilton',
+                'hamversion',
+                'username',
+                'computer',
+                'timestart',
+                'timestop',
+                'totalcputime']
+        """
+        return self.get_table_headings()
+
 
 class ConnectionWatchDog(Thread):
     """
@@ -109,14 +326,13 @@ class ConnectionWatchDog(Thread):
         self._queue.put(False)
         self.join()
 
-
 class AutorestoredConnection:
     def __init__(self, engine, timeout=60):
         self.engine = engine
         self._conn = None
         self._lock = Lock()
         self._watchdog = None
-        self._logger = pyiron_base.settings.logger.get_logger()
+        self._logger = logger
         self._timeout = timeout
 
     def execute(self, *args, **kwargs):
@@ -152,7 +368,7 @@ class AutorestoredConnection:
             self._conn.close()
 
 
-class DatabaseAccess(object):
+class DatabaseAccess(IsDatabase):
     """
     A core element of PyIron, which generally deals with accessing the database: getting, sending, changing some data
     to the db.
@@ -202,31 +418,136 @@ class DatabaseAccess(object):
         self.__reload_db()
         self.simulation_table = HistoricalTable(str(table_name), self.metadata)
         self.metadata.create_all()
-        self._viewer_mode = False
+        self._view_mode = False
 
-    @property
-    def viewer_mode(self):
-        """
-        Get viewer_mode - if viewer_mode is enable pyiron has read only access to the database.
+    def _get_view_mode(self):
+        return self._view_mode
 
-        Returns:
-            bool: returns TRUE when viewer_mode is enabled
+    @IsDatabase.view_mode.setter
+    def view_mode(self, value):
         """
-        return self._viewer_mode
-
-    @viewer_mode.setter
-    def viewer_mode(self, value):
-        """
-        Set viewer_mode - if viewer_mode is enable pyiron has read only access to the database.
+        Set view_mode - if view_mode is enable pyiron has read only access to the database.
 
         Args:
             value (bool): TRUE or FALSE
         """
         if isinstance(value, bool):
-            self._viewer_mode = value
+            self._view_mode = value
         else:
             raise TypeError("Viewmode can only be TRUE or FALSE.")
 
+    @IsDatabase.viewer_mode.setter
+    @deprecate("use view_mode")
+    def viewer_mode(self, value):
+        self.view_mode = value
+
+    def _job_dict(
+        self,
+        sql_query,
+        user,
+        project_path,
+        recursive,
+        job=None,
+        sub_job_name="%",
+        element_lst=None,
+    ):
+        """
+        Internal function to access the database from the project directly.
+
+        Args:
+            sql_query (str): SQL query to enter a more specific request
+            user (str): username of the user whoes user space should be searched
+            project_path (str): root_path - this is in contrast to the project_path in GenericPath
+            recursive (bool): search subprojects [True/False]
+            job (str): job_name - by default None
+            sub_job_name (str): path inside the HDF5 file - "%" by default to accept any path
+            element_lst (list): list of elements required in the chemical formular - by default None
+
+        Returns:
+            list: the function returns a list of dicts like get_items_sql, but it does not format datetime:
+                 [{'chemicalformula': u'Ni108',
+                  'computer': u'mapc157',
+                  'hamilton': u'LAMMPS',
+                  'hamversion': u'1.1',
+                  'id': 24,
+                  'job': u'DOF_1_0',
+                  'parentid': 21L,
+                  'project': u'lammps.phonons.Ni_fcc',
+                  'projectpath': u'D:/PyIron/PyIron_data/projects',
+                  'status': u'finished',
+                  'timestart': datetime.datetime(2016, 6, 24, 10, 17, 3, 140000),
+                  'timestop': datetime.datetime(2016, 6, 24, 10, 17, 3, 173000),
+                  'totalcputime': 0.033,
+                  'username': u'test'},
+                 {'chemicalformula': u'Ni108',
+                  'computer': u'mapc157',
+                  'hamilton': u'LAMMPS',
+                  'hamversion': u'1.1',
+                  'id': 21,
+                  'job': u'ref',
+                  'parentid': 20L,
+                  'project': u'lammps.phonons.Ni_fcc',
+                  'projectpath': u'D:/PyIron/PyIron_data/projects',
+                  'status': u'finished',
+                  'timestart': datetime.datetime(2016, 6, 24, 10, 17, 2, 429000),
+                  'timestop': datetime.datetime(2016, 6, 24, 10, 17, 2, 463000),
+                  'totalcputime': 0.034,
+                  'username': u'test'},.......]
+
+        """
+        dict_clause = {}
+        # FOR GET_ITEMS_SQL: clause = []
+        if user is not None:
+            dict_clause["username"] = str(user)
+            # FOR GET_ITEMS_SQL: clause.append("username = '" + self.user + "'")
+        if sql_query is not None:
+            # FOR GET_ITEMS_SQL: clause.append(self.sql_query)
+            if "AND" in sql_query:
+                cl_split = sql_query.split(" AND ")
+            elif "and" in sql_query:
+                cl_split = sql_query.split(" and ")
+            else:
+                cl_split = [sql_query]
+            dict_clause.update(
+                {str(element.split()[0]): element.split()[2] for element in cl_split}
+            )
+        if job is not None:
+            dict_clause["job"] = str(job)
+
+        if project_path == "./":
+            project_path = ""
+        if recursive:
+            dict_clause["project"] = str(project_path) + "%"
+        else:
+            dict_clause["project"] = str(project_path)
+        if sub_job_name is None:
+            dict_clause["subjob"] = None
+        elif sub_job_name != "%":
+            dict_clause["subjob"] = str(sub_job_name)
+        if element_lst is not None:
+            dict_clause["element_lst"] = element_lst
+
+        logger.debug("sql_query: %s", str(dict_clause))
+        return self.get_items_dict(dict_clause)
+
+    def _get_job_table(
+            self,
+            sql_query,
+            user,
+            project_path,
+            recursive=True,
+            columns=None,
+            element_lst=None,
+    ):
+        job_dict = self._job_dict(
+            sql_query=sql_query,
+            user=user,
+            project_path=project_path,
+            recursive=recursive,
+            element_lst=element_lst,
+        )
+        return pandas.DataFrame(job_dict, columns=columns)
+
     # Internal functions
     def __del__(self):
         """
@@ -269,7 +590,7 @@ class DatabaseAccess(object):
             return reg.search(item) is not None
 
     # Table functions
-    def get_table_headings(self, table_name=None):
+    def _get_table_headings(self, table_name=None):
         """
         Get column names
 
@@ -309,6 +630,8 @@ class DatabaseAccess(object):
             raise ValueError(str(table_name) + " does not exist")
         return [column.name for column in iter(simulation_list.columns)]
 
+
+
     def add_column(self, col_name, col_type):
         """
         Add an additional column - required for modification on the database
@@ -320,7 +643,7 @@ class DatabaseAccess(object):
         Returns:
 
         """
-        if not self._viewer_mode:
+        if not self._view_mode:
             if isinstance(col_name, list):
                 col_name = col_name[-1]
             if isinstance(col_type, list):
@@ -343,7 +666,7 @@ class DatabaseAccess(object):
         Returns:
 
         """
-        if not self._viewer_mode:
+        if not self._view_mode:
             if isinstance(col_name, list):
                 col_name = col_name[-1]
             if isinstance(col_type, list):
@@ -489,7 +812,7 @@ class DatabaseAccess(object):
         Returns:
             int: Database ID of the item created as an int, like: 3
         """
-        if not self._viewer_mode:
+        if not self._view_mode:
             try:
                 par_dict = self._check_chem_formula_length(par_dict)
                 par_dict = dict(
@@ -570,7 +893,7 @@ class DatabaseAccess(object):
         Returns:
 
         """
-        if not self._viewer_mode:
+        if not self._view_mode:
             if type(item_id) is list:
                 item_id = item_id[-1]  # sometimes a list is given, make it int
             if np.issubdtype(type(item_id), np.integer):
@@ -605,7 +928,7 @@ class DatabaseAccess(object):
         Returns:
 
         """
-        if not self._viewer_mode:
+        if not self._view_mode:
             self.conn.execute(
                 self.simulation_table.delete(
                     self.simulation_table.c["id"] == int(item_id)
