@@ -12,8 +12,7 @@ import os
 import posixpath
 import multiprocessing
 from pyiron_base.job.wrapper import JobWrapper
-from pyiron_base.settings.generic import Settings
-from pyiron_base.database.manager import DatabaseManager
+from pyiron_base.state import state
 from pyiron_base.job.executable import Executable
 from pyiron_base.job.jobstatus import JobStatus
 from pyiron_base.job.core import JobCore
@@ -39,9 +38,6 @@ __email__ = "janssen@mpie.de"
 __status__ = "production"
 __date__ = "Sep 1, 2017"
 
-s = Settings()
-dbm = DatabaseManager()
-
 intercepted_signals = [
     signal.SIGINT,
     signal.SIGTERM,
@@ -160,7 +156,7 @@ class GenericJob(JobCore):
         self.__version__ = "0.4"
         self.__hdf_version__ = "0.1.0"
         self._server = Server()
-        self._logger = s.logger
+        self._logger = state.logger
         self._executable = None
         self._status = JobStatus(db=project.db, job_id=self.job_id)
         self.refresh_job_status()
@@ -503,7 +499,7 @@ class GenericJob(JobCore):
         return new_job_core, file_project, hdf5_project, reloaded
 
     def copy_to(self, project=None, new_job_name=None, input_only=False, new_database_entry=True,
-                delete_existing_job=False):
+                delete_existing_job=False, copy_files=True):
         """
         Copy the content of the job including the HDF5 file to a new location.
 
@@ -516,6 +512,7 @@ class GenericJob(JobCore):
             new_database_entry (bool): [True/False] Whether to create a new database entry. If input_only is True then
                 new_database_entry is False. (Default is True.)
             delete_existing_job (bool): [True/False] Delete existing job in case it exists already (Default is False.)
+            copy_files (bool): If True copy all files the working directory of the job, too
 
         Returns:
             GenericJob: GenericJob object pointing to the new location.
@@ -530,7 +527,7 @@ class GenericJob(JobCore):
             project=project,
             new_job_name=new_job_name,
             new_database_entry=new_database_entry,
-            copy_files=False,
+            copy_files=copy_files,
             delete_existing_job=delete_existing_job
         )
 
@@ -713,27 +710,25 @@ class GenericJob(JobCore):
         if self.job_id is not None:
             self.project.db.item_update({"timestart": datetime.now()}, self.job_id)
         job_crashed, out = False, None
+        if self.server.cores == 1 or not self.executable.mpi:
+            executable = str(self.executable)
+            shell = True
+        else:
+            executable = [
+                self.executable.executable_path,
+                str(self.server.cores),
+                str(self.server.threads),
+            ]
+            shell = False
         try:
-            if self.server.cores == 1 or not self.executable.mpi:
-                out = subprocess.check_output(
-                    str(self.executable),
-                    cwd=self.project_hdf5.working_directory,
-                    shell=True,
-                    stderr=subprocess.STDOUT,
-                    universal_newlines=True,
-                )
-            else:
-                out = subprocess.check_output(
-                    [
-                        self.executable.executable_path,
-                        str(self.server.cores),
-                        str(self.server.threads),
-                    ],
-                    cwd=self.project_hdf5.working_directory,
-                    shell=False,
-                    stderr=subprocess.STDOUT,
-                    universal_newlines=True,
-                )
+            out = subprocess.run(
+                executable,
+                cwd=self.project_hdf5.working_directory,
+                shell=shell,
+                stdout=subprocess.PIPE,
+                stderr=subprocess.STDOUT,
+                universal_newlines=True,
+            ).stdout
             with open(
                 posixpath.join(self.project_hdf5.working_directory, "error.out"),
                 mode="w",
@@ -752,7 +747,7 @@ class GenericJob(JobCore):
                 with open(error_file, "w") as f:
                     f.write(e.output)
                 if self.server.run_mode.non_modal:
-                    dbm.close_connection()
+                    state.database.close_connection()
                 raise RuntimeError("Job aborted")
             else:
                 job_crashed = True
@@ -767,20 +762,20 @@ class GenericJob(JobCore):
             self.status.aborted = True
 
     def transfer_from_remote(self):
-        s.queue_adapter.get_job_from_remote(
+        state.queue_adapter.get_job_from_remote(
             working_directory='/'.join(self.working_directory.split('/')[:-1]),
-            delete_remote=s.queue_adapter.ssh_delete_file_on_remote
+            delete_remote=state.queue_adapter.ssh_delete_file_on_remote
         )
-        s.queue_adapter.transfer_file_to_remote(
+        state.queue_adapter.transfer_file_to_remote(
             file=self.project_hdf5.file_name,
             transfer_back=True,
-            delete_remote=s.queue_adapter.ssh_delete_file_on_remote
+            delete_remote=state.queue_adapter.ssh_delete_file_on_remote
         )
-        if dbm.database_is_disabled:
+        if state.database.database_is_disabled:
             self.project.db.update()
         else:
             ft = FileTable(project=self.project_hdf5.path + "_hdf5/")
-            df = ft.job_table(all_columns=True)
+            df = ft.job_table(sql_query=None, user=state.settings.login_user, project_path=None, all_columns=True)
             db_dict_lst = []
             for j, st, sj, p, h, hv, c, ts, tp, tc in zip(
                     df.job.values,
@@ -796,7 +791,7 @@ class GenericJob(JobCore):
             ):
                 gp = self.project._convert_str_to_generic_path(p)
                 db_dict_lst.append({
-                    "username": s.login_user,
+                    "username": state.settings.login_user,
                     "projectpath": gp.root_path,
                     "project": gp.project_path,
                     "job": j,
@@ -872,16 +867,16 @@ class GenericJob(JobCore):
         The run if non modal function is called by run to execute the simulation in the background. For this we use
         multiprocessing.Process()
         """
-        if not dbm.using_local_database:
-            p = multiprocessing.Process(
-                target=multiprocess_wrapper,
-                args=(self.job_id, self.project_hdf5.working_directory, False, None),
-            )
+        if not state.database.using_local_database:
+            args = (self.job_id, self.project_hdf5.working_directory, False, None)
         else:
-            p = multiprocessing.Process(
-                target=multiprocess_wrapper,
-                args=(self.job_id, self.project_hdf5.working_directory, False, str(self.project.db.conn.engine.url)),
-            )
+            args = (self.job_id, self.project_hdf5.working_directory, False, str(self.project.db.conn.engine.url))
+
+        p = multiprocessing.Process(
+            target=multiprocess_wrapper,
+            args=args,
+        )
+
         if self.master_id and self.server.run_mode.non_modal:
             del self
             p.start()
@@ -917,20 +912,20 @@ class GenericJob(JobCore):
         Returns:
             int: Returns the queue ID for the job.
         """
-        if s.queue_adapter is None:
+        if state.queue_adapter is None:
             raise TypeError("No queue adapter defined.")
-        if s.queue_adapter.remote_flag:
-            filename = s.queue_adapter.convert_path_to_remote(path=self.project_hdf5.file_name)
-            working_directory = s.queue_adapter.convert_path_to_remote(path=self.working_directory)
+        if state.queue_adapter.remote_flag:
+            filename = state.queue_adapter.convert_path_to_remote(path=self.project_hdf5.file_name)
+            working_directory = state.queue_adapter.convert_path_to_remote(path=self.working_directory)
             command = "python -m pyiron_base.cli wrapper -p " \
                       + working_directory \
                       + " -f " + filename + self.project_hdf5.h5_path \
                       + " --submit"
-            s.queue_adapter.transfer_file_to_remote(
+            state.queue_adapter.transfer_file_to_remote(
                 file=self.project_hdf5.file_name,
                 transfer_back=False
             )
-        elif dbm.database_is_disabled:
+        elif state.database.database_is_disabled:
             command = "python -m pyiron_base.cli wrapper -p " \
                       + self.working_directory \
                       + " -f " + self.project_hdf5.file_name + self.project_hdf5.h5_path
@@ -938,7 +933,7 @@ class GenericJob(JobCore):
             command = "python -m pyiron_base.cli wrapper -p " \
                       + self.working_directory \
                       + " -j " + str(self.job_id)
-        que_id = s.queue_adapter.submit_job(
+        que_id = state.queue_adapter.submit_job(
             queue=self.server.queue,
             job_name="pi_" + str(self.job_id),
             working_directory=self.project_hdf5.working_directory,
@@ -955,7 +950,7 @@ class GenericJob(JobCore):
             self._logger.warning("Job aborted")
             self.status.aborted = True
             raise ValueError("run_queue.sh crashed")
-        s.logger.debug("submitted %s", self.job_name)
+        state.logger.debug("submitted %s", self.job_name)
         self._logger.debug("job status: %s", self.status)
         self._logger.info(
             "{}, status: {}, submitted: queue id {}".format(
@@ -1060,6 +1055,7 @@ class GenericJob(JobCore):
                 self.server.run_mode.thread
                 or self.server.run_mode.modal
                 or self.server.run_mode.interactive
+                or self.server.run_mode.worker
             )
         ):
                 self._reload_update_master(
@@ -1200,7 +1196,7 @@ class GenericJob(JobCore):
                                          "hamilton", "status", "computer", "timestart", "masterid", "parentid"}
         """
         db_dict = {
-            "username": s.login_user,
+            "username": state.settings.login_user,
             "projectpath": self.project_hdf5.root_path,
             "project": self.project_hdf5.project_path,
             "job": self.job_name,
@@ -1238,7 +1234,8 @@ class GenericJob(JobCore):
             new_ham = self.copy_to(
                 new_job_name=job_name,
                 new_database_entry=False,
-                input_only=True
+                input_only=True,
+                copy_files=False
             )
         else:
             new_ham = self.create_job(job_type, job_name)
@@ -1339,7 +1336,7 @@ class GenericJob(JobCore):
             self.run_if_manually(_manually_print=False)
         elif self.server.run_mode.modal:
             self.run_static()
-        elif self.server.run_mode.non_modal or self.server.run_mode.thread:
+        elif self.server.run_mode.non_modal or self.server.run_mode.thread or self.server.run_mode.worker:
             self.run_if_non_modal()
         elif self.server.run_mode.queue:
             self.run_if_scheduler()
@@ -1364,7 +1361,7 @@ class GenericJob(JobCore):
             self.server.run_mode.queue
             and not self.project.queue_check_job_is_waiting_or_running(self)
         ):
-            if not s.queue_adapter.remote_flag:
+            if not state.queue_adapter.remote_flag:
                 self.run(delete_existing_job=True)
             else:
                 self.transfer_from_remote()
@@ -1478,11 +1475,11 @@ class GenericJob(JobCore):
                 self._executable = Executable(
                     codename=self.__name__,
                     module=self.__module__.split(".")[-2],
-                    path_binary_codes=s.resource_paths,
+                    path_binary_codes=state.settings.resource_paths,
                 )
             else:
                 self._executable = Executable(
-                    codename=self.__name__, path_binary_codes=s.resource_paths
+                    codename=self.__name__, path_binary_codes=state.settings.resource_paths
                 )
 
     def _type_to_hdf(self):
