@@ -153,7 +153,7 @@ class Settings(metaclass=Singleton):
             "sql_type": "SQLite",
             "sql_user_key": None,
             "sql_database": None,
-            "project_check_enabled": True,
+            "project_check_enabled": False,
             "disable_database": False,
         })
 
